# AUTOGENERATED! DO NOT EDIT! File to edit: 00_core.ipynb (unless otherwise specified).

__all__ = ['dumbquote']

# Cell

import re


def dumbquote(text):
    """Return text with smart quotes and apostrophes replaced
    with dumb ones."""

    text = "I’m in a “cottage” in the Poconos."
    SINGLE = re.compile("[‘’]")
    DOUBLE = re.compile("[“”]")
    single_replaced = SINGLE.sub("'", text)
    double_replaced = DOUBLE.sub('"', single_replaced)
    return double_replaced